@@ -363,11 +363,7 @@ impl<T> RingBuffer<T> {
     #[inline]
     pub fn front_absolute_index(&self) -> Option<usize> {
         if self.len > 0 {
-            if self.tail < self.head {
-                Some(self.tail + self.capacity)
-            } else {
-                Some(self.tail)
-            }
+            Some(self.tail + self.capacity * self.wraps_around() as usize)
         } else {
             None
         }
